@@ -1,5 +1,6 @@
 import datetime
 import getpass
+import pathlib
 import socket
 import sys
 import time
@@ -40,12 +41,19 @@ class RemoteRunner:
     port: int = 8888
     conda_env: str = None
     notebook_dir: str = None
+    notebook: str = None
     port_forwarding: bool = True
     launch_command: str = None
     identity: str = None
     shell: str = '/usr/bin/sh -l'
 
     def __post_init__(self):
+        if self.notebook_dir is not None and self.notebook is not None:
+            raise ValueError('`notebook_dir` and `notebook` are mutually exclusive')
+        if self.notebook:
+            self.notebook = pathlib.Path(self.notebook)
+            self.notebook_dir = str(self.notebook.parent)
+            self.notebook = self.notebook.name
         console.rule('[bold green]Authentication', characters='*')
         if self.port_forwarding and not is_port_available(self.port):
             console.print(
@@ -129,7 +137,7 @@ class RemoteRunner:
             time.sleep(
                 3
             )  # don't want open_browser to run before the forwarding is actually working
-            open_browser(port=local_port, token=self.parsed_result['token'])
+            open_browser(port=local_port, token=self.parsed_result['token'], path=self.notebook)
             self.run_command(f'tail -f {self.log_file}')
 
     def close(self):
@@ -153,11 +161,23 @@ class RemoteRunner:
             )
 
     def _launch_jupyter(self):
+
+        console.rule(
+            '[bold green]Running jupyter sanity checks (ensuring `jupyter` is in `$PATH`)',
+            characters='*',
+        )
         check_jupyter_status = 'sh -c "command -v jupyter"'
+        conda_activate_cmd = 'source activate'
         if self.conda_env:
-            check_jupyter_status = f'source activate {self.conda_env} && sh -c "command -v jupyter"'
-        console.rule('[bold green]Running jupyter sanity checks', characters='*')
-        self.run_command(command=check_jupyter_status)
+            try:
+                self.run_command(f'{conda_activate_cmd} {self.conda_env} && {check_jupyter_status}')
+            except SystemExit:
+                console.print(f'`{conda_activate_cmd}` failed. Trying `conda activate`...')
+                self.run_command(f'conda activate {self.conda_env} && {check_jupyter_status}')
+                conda_activate_cmd = 'conda activate'
+
+        else:
+            self.run_command(check_jupyter_status)
         console.rule(
             f'[bold green] Checking $TMPDIR and $HOME on {self.session.host}', characters='*'
         )
@@ -186,7 +206,7 @@ class RemoteRunner:
             command = f'{command} --notebook-dir={self.notebook_dir}'
         command = f'{command} >& {self.log_file}'
         if self.conda_env:
-            command = f'source activate {self.conda_env} && {command}'
+            command = f'{conda_activate_cmd} {self.conda_env} && {command}'
 
         if self.launch_command:
             console.rule('[bold green]Preparing Batch Job script', characters='*')
@@ -220,7 +240,7 @@ class RemoteRunner:
         if self.port_forwarding:
             self.setup_port_forwarding()
         else:
-            open_browser(url=self.parsed_result['url'])
+            open_browser(url=self.parsed_result['url'], path=self.notebook)
             self.run_command(command=f'tail -f {self.log_file}')
 
     def _check_log_file_dir(self, check_dir_command, arg1, arg2):
@@ -232,7 +252,7 @@ class RemoteRunner:
             self.log_dir = arg2
 
 
-def open_browser(port: int = None, token: str = None, url: str = None):
+def open_browser(port: int = None, token: str = None, url: str = None, path=None):
     """Opens notebook interface in a new browser window.
 
     Parameters
@@ -243,6 +263,8 @@ def open_browser(port: int = None, token: str = None, url: str = None):
         token used for authentication, by default None
     url : str, optional
         Notebook url, by default None
+    path : str, optional
+        Notebook path
 
     Raises
     ------
@@ -258,6 +280,7 @@ def open_browser(port: int = None, token: str = None, url: str = None):
         url = f'http://localhost:{port}'
         if token:
             url = f'{url}/?token={token}'
+        url = f'{url}/lab/tree/{path}' if path else url
 
     console.rule('[bold green]Opening Jupyter Lab interface in a browser', characters='*')
     console.print(f'Jupyter Lab URL: {url}')
@@ -268,9 +291,7 @@ def open_browser(port: int = None, token: str = None, url: str = None):
 def is_port_available(port):
     socket_for_port_check = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     status = socket_for_port_check.connect_ex(('localhost', int(port)))
-    if status == 0:  # Port is in use
-        return False
-    return True
+    return status != 0
 
 
 def parse_stdout(stdout: str):
